import classnames from 'classnames';
import PropTypes from 'prop-types';
import { always, head, ifElse, isNil, lte, map, pipe, reject, unless } from 'ramda';
import React from 'react';
import { IconUser } from '../icons/icon-user/icon-user';

export const AVATAR_SIZES = [64, 200, 384];

export const Avatar = ({
  url, length, tag, innerTag, className, ...otherProps
}) => {
  const Tag = tag;
  const normalizedLength = parseInt(length, 10);
  const resizedImageUrl = pipe(
    map(unless(lte(normalizedLength), always(null))),
    reject(isNil),
    head,
    ifElse(isNil, always(url), size => `${url}_${size}`)
  )(AVATAR_SIZES);

  const baseProps = {
    className: classnames('rounded-circle', className),
    style: {
      height: normalizedLength,
      width: normalizedLength,
      backgroundImage: `url(${resizedImageUrl})`,
      backgroundSize: 'cover',
      backgroundPosition: 'center center',
    },
  };

  if (innerTag) {
    baseProps.tag = innerTag;
  }

  return url ? (
    <Tag {...baseProps} {...otherProps} />
  ) : (
    <div className={className} style={{ height: normalizedLength, width: normalizedLength }}>
      <IconUser className="h-100 w-100" />
    </div>
  );
};

Avatar.propTypes = {
  length: PropTypes.string.isRequired,
  url: PropTypes.string,
  tag: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),
  innerTag: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),
  className: PropTypes.string,
};

Avatar.defaultProps = {
  url: null,
  tag: 'div',
  innerTag: null,
  className: null,
};
